# tred
Dimensionality reduction algorithms for high-dimensional time-series data. 

Built on top of the `scikit-learn` library, adhering to the familiar Python
machine-learning `fit`-`transform` interface. 

See [GitHub page](https://github.com/brendanlu/tred) for more information, 
examples, and relevant literature. The library is written in pure Python, with 
a focus on efficient implementations using underlying NumPy algorithms. 

Contact brendannlu5@gmail.com if you are interested in using this for your 
research, and want some support. 
